@@ -65,10 +65,18 @@
 #' @importFrom preprocessCore normalize.quantiles
 #' @importFrom InterpretMSSpectrum findMAIN PlotSpec
 #' @importFrom xcms groupval featureValues
+#' @importFrom utils citation packageVersion
 
 #' @references Broeckling CD, Afsar FA, Neumann S, Ben-Hur A, Prenni JE. RAMClust: a novel feature clustering method enables spectral-matching-based annotation for metabolomics data. Anal Chem. 2014 Jul 15;86(14):6812-7. doi: 10.1021/ac501530d.  Epub 2014 Jun 26. PubMed PMID: 24927477.
 #' @references Broeckling CD, Ganna A, Layer M, Brown K, Sutton B, Ingelsson E, Peers G, Prenni JE. Enabling Efficient and Confident Annotation of LC-MS Metabolomics Data through MS1 Spectrum and Time Prediction. Anal Chem. 2016 Sep 20;88(18):9226-34. doi: 10.1021/acs.analchem.6b02479. Epub 2016 Sep 8. PubMed PMID: 7560453.
-#' @keywords 'ramclustR' 'RAMClustR', 'ramclustR', 'metabolomics', 'mass spectrometry', 'clustering', 'feature', 'xcms'
+#' @concept ramclustR
+#' @concept RAMClustR
+#' @concept metabolomics
+#' @concept mass spectrometry
+#' @concept clustering
+#' @concept feature
+#' @concept MSFinder
+#' @concept xcms
 #' @author Corey Broeckling
 #' @export
 
@@ -229,6 +237,8 @@ ramclustR  <- function(xcmsObj=NULL,
     if(is.null(maxt)) maxt<-st*20
     
     history <- paste(history,
+                     " XCMS",  paste0("(v.", packageVersion('xcms'), ")"), "was used for feature detection and retention time alighment. ",
+                     "Processing was performed using R", paste0("(v.", citation()$author, " ",  citation()$year, ")."),
                      " Feature data was input as an xcms object with ramclustR parameter settings of ",
                      " st = ", st,
                      " sr = ", sr,
